import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = 
  'https://gist.githubusercontent.com/anushaanumula/85d1a14655cde3fc775af1a07289c1b4/raw/b4d50fe41503c1739b4c0dcdeb7e379b342abfca/PS4_Sales.csv';
const parseRow = (d) => {
  d.Year = +d.Year;
  d.Global = +d.Global;
  d.NorthAmerica = +d.NorthAmerica;
  d.Europe = +d.Europe;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.Global)
    .yValue((d) => d.Year)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 130,
    })
    .radius(5);

  svg.call(plot);
 
        svg.append('text')
          .attr('class', 'axis-label')
          .attr('x', -innerHeight / 2)
          .attr('y', 38)
          .attr('fill', 'black')
          .style("font", "25px times")
          .style('text-anchor', 'Center')
          .attr('transform', `rotate(-90)`)
          .text('PS4 sale year');
  const columns = [
    'Global',
    'NorthAmerica',
    'Europe',
    'Year',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();



